@@ -95,6 +95,7 @@ from .utils import (
     PendingRequest,
     ainput,
     str_to_base64,
+    strip_phone_number_symbols,
 )
 
 RequestResult = TypeVar('RequestResult', bound=BaseObject)
@@ -270,6 +271,13 @@ class ClientSettings(pydantic.BaseSettings):
 
         return value
 
+    @validator('phone_number')
+    def validator_phone_number(cls, value):
+        if bool(value):
+            return strip_phone_number_symbols(value)
+
+        return value
+
     @validator('database_encryption_key', pre=True)
     def validator_database_encryption_key(cls, value):
         if not bool(value):
@@ -480,10 +488,12 @@ class Client:
         return code
 
     async def __auth_get_password(self) -> str:
-        password = self.settings.password.get_secret_value()
+        password = self.settings.password
 
         if not bool(password):
             password = await ainput('Enter 2FA password:', secured=True)
+        else:
+            password = password.get_secret_value()
 
         return password
 
@@ -800,7 +810,7 @@ class Client:
 
     async def start(self) -> 'Client':
         self.logger.info('Starting client')
-        self.logger.info(f'Session workdir: {self.settings.files_directory}')
+        self.logger.info(f'Session workdir: {self.settings.files_directory.absolute()}')
 
         # Preparing middlewares handlers
         self.__middlewares_handlers = list(reversed(self.__middlewares))
