@@ -11,9 +11,15 @@ import ujson
 
 TDLIB_MAX_INT = 2 ** 63 - 1
 log_message_callback_type = CFUNCTYPE(None, c_int, c_char_p)
-LINUX_MACHINE_SYNONYMS = {
+ARCH_ALIASES = {
     "x86_64": "amd64",
-    "aarch64": "arm64"
+    "aarch64": "arm64",
+    "arm64v8": "arm64",
+}
+
+SYSTEM_LIB_EXTENSION = {
+    'darwin': 'dylib',
+    'linux': 'so',
 }
 
 
@@ -25,23 +31,14 @@ def _get_tdjson_lib_path() -> str:
 
     uname = platform.uname()
     system_name = uname.system.lower()
-    machine_name = uname.machine
+    machine_name = uname.machine.lower()
+    machine_name = ARCH_ALIASES.get(machine_name, machine_name)
+    extension = SYSTEM_LIB_EXTENSION.get(system_name)
 
-    if system_name == 'darwin':
-        extension = f"dylib"
-    elif system_name == 'linux':
-        extension = f"so"
+    if not bool(extension):
+        raise RuntimeError('Prebuilt TDLib binary is not included for this system')
 
-        if machine_name in LINUX_MACHINE_SYNONYMS.keys():
-            machine_name = LINUX_MACHINE_SYNONYMS[machine_name]
-    else:
-        raise RuntimeError('Prebuilt TDLib binary is not include for this system')
-
-    binary_path = f'tdlib/{system_name}/{machine_name}/libtdjson.{extension}'
-
-    if not pkg_resources.resource_exists('aiotdlib', binary_path):
-        # Binary for arm64 machines will be always provided for both Darwin and Linux
-        binary_path = f"tdlib/{system_name}/arm64/libtdjson.{extension}"
+    binary_path = f'tdlib/libtdjson_{system_name}_{machine_name}.{extension}'
 
     return pkg_resources.resource_filename('aiotdlib', binary_path)
 
@@ -65,7 +62,6 @@ class TDJson:
     __td_receive: typing.Callable[[float], bytes]
     __td_send: typing.Callable[[int, bytes], None]
     __td_execute: typing.Callable[[bytes], bytes]
-    __td_set_log_verbosity_level: typing.Callable[[int], None]
     __td_set_log_message_callback: typing.Callable[[log_message_callback_type], None]
 
     td_json_client: typing.Optional[int] = None
@@ -116,20 +112,15 @@ class TDJson:
         self.__td_set_log_message_callback.restype = None
         self.__td_set_log_message_callback.argtypes = [log_message_callback_type]
 
-        # td_set_log_verbosity_level
-        self.__td_set_log_verbosity_level = self.__tdjson.td_set_log_verbosity_level
-        self.__td_set_log_verbosity_level.restype = None
-        self.__td_set_log_verbosity_level.argtypes = [c_int]
-
     def initialize(self, library_path: str, verbosity: TDLibLogVerbosity) -> None:
         self.inject_library(library_path)
 
         if bool(self.td_json_client):
             raise RuntimeError('TDJson instance is already initialized')
 
-        self.__td_set_log_verbosity_level(int(verbosity))
         self.__td_set_log_message_callback(log_message_callback_type(self.__log_message_callback))
         self.td_json_client = self.__td_create_client_id()
+        self.execute({'@type': 'setLogVerbosityLevel', 'new_verbosity_level': verbosity})
 
     def send(self, query: dict):
         if not bool(self.td_json_client):
@@ -165,6 +156,7 @@ class TDJson:
             # Each returned object will have an "@client_id" field,
             # containing the identifier of the client for which a response or an update was received.
             if result.pop('@client_id', None) != self.td_json_client:
+                # TODO: Support handling multiple clients with single TDJson instance
                 return None
 
         return result
